networkinference package
========================

inference module
----------------

.. currentmodule:: networkinference

.. autosummary::
   :toctree: _autosummary
   :template: custom-class-template.rst
   :recursive:

   networkinference.OLS
   networkinference.TSLS
   networkinference.IPW

Other modules
-------------

.. toctree::
   :maxdepth: 1

   networkinference.core
   networkinference.utils

